==> claroline-1.8.11.tbz: www/claroline/claroline/lang/spanish/locale_settings.php <==
<?php // $Id: locale_settings.php 9707 2007-12-12 13:46:31Z mlaurent $
/**
 * CLAROLINE
 * Spanish Translation
 * @version 1.8 $Revision: 9707 $
 *
 * @copyright (c) 2001-2006 Universite catholique de Louvain (UCL)
 *
 * @license http://www.gnu.org/copyleft/gpl.html (GPL) GENERAL PUBLIC LICENSE 
 *
 * @package LANG-ES
 *
 * @author Claro team <cvs@claroline.net>
 */
$englishLangName = "Spanish";
$localLangName = "espaol";

$iso639_1_code = "es";
$iso639_2_code = "spa";

$langNameOfLang['arabic'		]="rabe";
$langNameOfLang['brazilian'		]="portugus";
$langNameOfLang['bulgarian'		]="bulgarian";
$langNameOfLang['croatian'		]="croato";
$langNameOfLang['dutch'			]="dutch";
$langNameOfLang['english'		]="ingls";
$langNameOfLang['finnish'		]="finlands";
$langNameOfLang['french'		]="francs";
$langNameOfLang['german'		]="alemn";
$langNameOfLang['greek'			]="griego";
$langNameOfLang['italian'		]="italiano";
$langNameOfLang['japanese'		]="japons";
$langNameOfLang['polish'		]="polaco";
$langNameOfLang['simpl_chinese'		]="chino";
$langNameOfLang['spanish'		]="espaol";
$langNameOfLang['spanish_latin'		]="espaol latin";
$langNameOfLang['swedish'		]="sueco";
$langNameOfLang['thai'			]="thailands";
$langNameOfLang['turkish'		]="turco";

$charset = 'iso-8859-1';
$text_dir = 'ltr'; // ('ltr' para izq a der, 'rtl' para der a izq)
$left_font_family = 'verdana, helvetica, arial, geneva, sans-serif';
$right_font_family = 'helvetica, arial, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$langDay_of_weekNames['init'] = array('S', 'M', 'T', 'W', 'T', 'F', 'S');
$langDay_of_weekNames['short'] = array('Dom', 'Lun', 'Mar', 'Mier', 'Jue', 'Vie', 'Sab');
$langDay_of_weekNames['long'] = array('Domingo', 'Lunes', 'Martes', 'Mircoles', 'Jueves', 'Viernes', 'Sbado');

$langMonthNames['init']  = array('E', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D');
$langMonthNames['short'] = array('Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'Oct', 'Nov', 'Dic');
$langMonthNames['long'] = array('Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Dicembre');

// Voir http://www.php.net/manual/en/function.strftime.php pour la variable
// ci-dessous

$dateFormatShort =  "%b %d, %y";
$dateFormatLong  = '%A %B %d, %Y';
$dateTimeFormatLong  = '%B %d, %Y at %I:%M %p';
$timeNoSecFormat = '%I:%M %p';


?>

==> claroline-1.9.3.tbz: www/claroline/claroline/lang/spanish/locale_settings.php <==
<?php // $Id: locale_settings.php 11750 2009-05-06 07:05:54Z dimitrirambout $
/**
 * CLAROLINE
 * Spanish Translation
 * @version 1.9 $Revision: 11750 $
 *
 * @copyright (c) 2001-2006 Universite catholique de Louvain (UCL)
 *
 * @license http://www.gnu.org/copyleft/gpl.html (GPL) GENERAL PUBLIC LICENSE 
 *
 * @package LANG-ES
 *
 * @author Claro team <cvs@claroline.net>
 */
$englishLangName = "Spanish";
$localLangName = "espaol";

$iso639_1_code = "es";
$iso639_2_code = "spa";

$langNameOfLang['arabic'		]="rabe";
$langNameOfLang['brazilian'		]="portugus";
$langNameOfLang['bulgarian'		]="blgaro";
$langNameOfLang['croatian'		]="croata";
$langNameOfLang['dutch'			]="holands";
$langNameOfLang['english'		]="ingls";
$langNameOfLang['finnish'		]="finlands";
$langNameOfLang['french'		]="francs";
$langNameOfLang['german'		]="alemn";
$langNameOfLang['greek'			]="griego";
$langNameOfLang['italian'		]="italiano";
$langNameOfLang['japanese'		]="japons";
$langNameOfLang['polish'		]="polaco";
$langNameOfLang['simpl_chinese'		]="chino";
$langNameOfLang['spanish'		]="espaol";
$langNameOfLang['spanish_latin'		]="espaol latino";
$langNameOfLang['swedish'		]="sueco";
$langNameOfLang['thai'			]="tailands";
$langNameOfLang['turkish'		]="turco";

$charset = 'iso-8859-1';
$text_dir = 'ltr'; // ('ltr' para izq a der, 'rtl' para der a izq)
$left_font_family = 'verdana, helvetica, arial, geneva, sans-serif';
$right_font_family = 'helvetica, arial, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$langDay_of_weekNames['init'] = array('D', 'L', 'M', 'X', 'J', 'V', 'S');
$langDay_of_weekNames['short'] = array('Dom', 'Lun', 'Mar', 'Mie', 'Jue', 'Vie', 'Sab');
$langDay_of_weekNames['long'] = array('Domingo', 'Lunes', 'Martes', 'Mircoles', 'Jueves', 'Viernes', 'Sbado');

$langMonthNames['init']  = array('E', 'F', 'M', 'A', 'M', 'J', 'J', 'A', 'S', 'O', 'N', 'D');
$langMonthNames['short'] = array('Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'Oct', 'Nov', 'Dic');
$langMonthNames['long'] = array('Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre');

// Voir http://www.php.net/manual/en/function.strftime.php pour la variable
// ci-dessous

$dateFormatShort =  "%d/%m/%Y";
$dateFormatLong  = '%A, %e de %B de %Y';
$dateTimeFormatLong  = '%e de %B de %Y a las %H:%M';
$timeNoSecFormat = '%H:%M';


?>
